==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/Union.h <==
// public abstract class soot.jimple.toolkits.pointer.Union

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9dbbb271543e0b8f soot_jimple_toolkits_pointer_Union

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_Union_H_
#define _JC_soot_jimple_toolkits_pointer_Union_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Set$object;
struct _jc_soot_PointsToSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_Union$sub_refs	_jc_soot_jimple_toolkits_pointer_Union$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_Union$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_Union$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_Union$refs	_jc_soot_jimple_toolkits_pointer_Union$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_Union$nonrefs	_jc_soot_jimple_toolkits_pointer_Union$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_Union$object	_jc_soot_jimple_toolkits_pointer_Union$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_Union$vmethods	_jc_soot_jimple_toolkits_pointer_Union$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_Union$vtable	_jc_soot_jimple_toolkits_pointer_Union$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_Union$vtype	_jc_soot_jimple_toolkits_pointer_Union$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_Union$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_Union$object *);

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_pointer_Union$method$addAll$ee80ba7ccfb17ce5(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_Union$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_pointer_Union$method$possibleClassConstants$6e3226531d53717d(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_Union$object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_pointer_Union$method$possibleStringConstants$f7b905484b329d7f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_Union$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_Union$method_info$addAll$ee80ba7ccfb17ce5;
extern _jc_method _jc_soot_jimple_toolkits_pointer_Union$method_info$possibleClassConstants$6e3226531d53717d;
extern _jc_method _jc_soot_jimple_toolkits_pointer_Union$method_info$possibleStringConstants$f7b905484b329d7f;

// Static methods
extern jboolean _jc_soot_jimple_toolkits_pointer_Union$method$hasNonEmptyIntersection$2a607e63417be48d(_jc_env *, struct _jc_object *, struct _jc_object *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_Union$vmethods {
	jboolean	(*addAll$ee80ba7ccfb17ce5)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_Union$object *, struct _jc_object *);
	struct _jc_object	*(*possibleClassConstants$6e3226531d53717d)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_Union$object *);
	struct _jc_object	*(*possibleStringConstants$f7b905484b329d7f)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_Union$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_Union$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_Union$vmethods	soot_jimple_toolkits_pointer_Union;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_Union$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_Union$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_Union$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_Union$refs {
    _jc_soot_jimple_toolkits_pointer_Union$sub_refs	soot_jimple_toolkits_pointer_Union;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_Union$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_Union$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_Union$sub_nonrefs	soot_jimple_toolkits_pointer_Union;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_Union$object {
	_jc_soot_jimple_toolkits_pointer_Union$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_Union$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_Union$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_Union$vtype _jc_soot_jimple_toolkits_pointer_Union$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_Union, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_Union$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_Union_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/Union.h <==
// public abstract class soot.jimple.toolkits.pointer.Union

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9dbbb271543e0b8f soot_jimple_toolkits_pointer_Union

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_Union_H_
#define _JC_soot_jimple_toolkits_pointer_Union_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Set$object;
struct _jc_soot_PointsToSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_Union$sub_refs	_jc_soot_jimple_toolkits_pointer_Union$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_Union$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_Union$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_Union$refs	_jc_soot_jimple_toolkits_pointer_Union$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_Union$nonrefs	_jc_soot_jimple_toolkits_pointer_Union$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_Union$object	_jc_soot_jimple_toolkits_pointer_Union$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_Union$vmethods	_jc_soot_jimple_toolkits_pointer_Union$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_Union$vtable	_jc_soot_jimple_toolkits_pointer_Union$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_Union$vtype	_jc_soot_jimple_toolkits_pointer_Union$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_Union$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_Union$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_pointer_Union$method$addAll$ee80ba7ccfb17ce5(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_Union$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_pointer_Union$method$possibleClassConstants$6e3226531d53717d(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_Union$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_pointer_Union$method$possibleStringConstants$f7b905484b329d7f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_Union$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_Union$method_info$addAll$ee80ba7ccfb17ce5;
extern _jc_method _jc_soot_jimple_toolkits_pointer_Union$method_info$possibleClassConstants$6e3226531d53717d;
extern _jc_method _jc_soot_jimple_toolkits_pointer_Union$method_info$possibleStringConstants$f7b905484b329d7f;

// Static methods
extern jboolean _jc_soot_jimple_toolkits_pointer_Union$method$hasNonEmptyIntersection$2a607e63417be48d(_jc_env *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_Union$vmethods {
	jboolean	(*addAll$ee80ba7ccfb17ce5)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_Union$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*possibleClassConstants$6e3226531d53717d)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_Union$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*possibleStringConstants$f7b905484b329d7f)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_Union$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_Union$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_Union$vmethods	soot_jimple_toolkits_pointer_Union;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_Union$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_Union$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_Union$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_Union$refs {
    _jc_soot_jimple_toolkits_pointer_Union$sub_refs	soot_jimple_toolkits_pointer_Union;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_Union$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_Union$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_Union$sub_nonrefs	soot_jimple_toolkits_pointer_Union;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_Union$object {
	_jc_soot_jimple_toolkits_pointer_Union$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_Union$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_Union$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_Union$vtype _jc_soot_jimple_toolkits_pointer_Union$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_Union, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_Union$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_Union_H_ */
